@@ -31,6 +31,15 @@
   }, {
     id: 'downshift-1-item-1',
     label: 'Option 2'
+  }, {
+    id: 'downshift-1-item-2',
+    label: 'Option 3'
+  }, {
+    id: 'downshift-1-item-3',
+    label: 'Option 4'
+  }, {
+    id: 'downshift-1-item-4',
+    label: 'An example option that is really long to show what should be done to handle long text'
   }];
   module.exports = {
     context: {
